<?php declare(strict_types=1);


namespace Pinpoint\DropShipping\Api;

use Magento\Framework\Api\SearchCriteriaInterface;


interface SupplierRepositoryInterface
{

    /**
     * Save Supplier
     * @param \Pinpoint\DropShipping\Api\Data\SupplierInterface $supplier
     * @return \Pinpoint\DropShipping\Api\Data\SupplierInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function save(
        \Pinpoint\DropShipping\Api\Data\SupplierInterface $supplier
    );

    /**
     * Retrieve Supplier
     * @param string $supplierId
     * @return \Pinpoint\DropShipping\Api\Data\SupplierInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function get($supplierId);

    /**
     * Retrieve Supplier matching the specified criteria.
     * @param \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
     * @return \Pinpoint\DropShipping\Api\Data\SupplierSearchResultsInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getList(
        \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
    );

    /**
     * Delete Supplier
     * @param \Pinpoint\DropShipping\Api\Data\SupplierInterface $supplier
     * @return bool true on success
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function delete(
        \Pinpoint\DropShipping\Api\Data\SupplierInterface $supplier
    );

    /**
     * Delete Supplier by ID
     * @param string $supplierId
     * @return bool true on success
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function deleteById($supplierId);
}

