<?php declare(strict_types=1);


namespace Pinpoint\DropShipping\Model;

use Magento\Framework\Api\DataObjectHelper;
use Pinpoint\DropShipping\Api\Data\SupplierInterface;
use Pinpoint\DropShipping\Api\Data\SupplierInterfaceFactory;


class Supplier extends \Magento\Framework\Model\AbstractModel
{

    protected $supplierDataFactory;

    protected $_eventPrefix = 'pinpoint_dropshipping_supplier';
    protected $dataObjectHelper;


    /**
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param SupplierInterfaceFactory $supplierDataFactory
     * @param DataObjectHelper $dataObjectHelper
     * @param \Pinpoint\DropShipping\Model\ResourceModel\Supplier $resource
     * @param \Pinpoint\DropShipping\Model\ResourceModel\Supplier\Collection $resourceCollection
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        SupplierInterfaceFactory $supplierDataFactory,
        DataObjectHelper $dataObjectHelper,
        \Pinpoint\DropShipping\Model\ResourceModel\Supplier $resource,
        \Pinpoint\DropShipping\Model\ResourceModel\Supplier\Collection $resourceCollection,
        array $data = []
    ) {
        $this->supplierDataFactory = $supplierDataFactory;
        $this->dataObjectHelper = $dataObjectHelper;
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * Retrieve supplier model with supplier data
     * @return SupplierInterface
     */
    public function getDataModel()
    {
        $supplierData = $this->getData();
        
        $supplierDataObject = $this->supplierDataFactory->create();
        $this->dataObjectHelper->populateWithArray(
            $supplierDataObject,
            $supplierData,
            SupplierInterface::class
        );
        
        return $supplierDataObject;
    }
}

